# jojogif

将视频转成gif，并添加标准结尾

## 安装

```bash
pip3 install jojogif
```

#### 普通转换

```bash
jojogif --path video-path --begin 1 --end 2.2 --out-path ./
```

#### 添加标准结局

```bash
jojogif --path video-path --begin 1 --end 2.2 --out-path ./ --jojo true
```

#### 示例

![image/example.gif](./image/to_be_continued.png)